@@ -167,6 +167,24 @@ class ConfigTest(CoverageTest):
         with pytest.raises(ConfigError, match=msg):
             coverage.Coverage()
 
+    @pytest.mark.parametrize("force", [False, True])
+    def test_force_environment(self, force: bool) -> None:
+        self.make_file(".coveragerc", """\
+            [run]
+            debug = dataio, pids
+            """)
+        self.make_file("force.ini", """\
+            [run]
+            debug = callers, fooey
+            """)
+        if force:
+            self.set_environ("COVERAGE_FORCE_CONFIG", "force.ini")
+        cov = coverage.Coverage()
+        if force:
+            assert cov.config.debug == ["callers", "fooey"]
+        else:
+            assert cov.config.debug == ["dataio", "pids"]
+
     @pytest.mark.parametrize("bad_config, msg", [
         ("[run]\ntimid = maybe?\n", r"maybe[?]"),
         ("timid = 1\n", r"no section headers"),
@@ -295,7 +313,11 @@ class ConfigTest(CoverageTest):
             s = s.replace("~joe/", "/Users/joe/")
             return s
 
-        with mock.patch.object(coverage.config.os.path, 'expanduser', new=expanduser):
+        with mock.patch.object(
+            coverage.config.os.path,  # type: ignore[attr-defined]
+            'expanduser',
+            new=expanduser
+        ):
             cov = coverage.Coverage()
         assert cov.config.data_file == "/Users/me/data.file"
         assert cov.config.html_dir == "/Users/joe/html_dir"
@@ -334,7 +356,11 @@ class ConfigTest(CoverageTest):
             s = s.replace("~joe/", "/Users/joe/")
             return s
 
-        with mock.patch.object(coverage.config.os.path, 'expanduser', new=expanduser):
+        with mock.patch.object(
+            coverage.config.os.path, # type: ignore[attr-defined]
+            'expanduser',
+            new=expanduser
+        ):
             cov = coverage.Coverage()
         assert cov.config.data_file == "/Users/me/data.file"
         assert cov.config.html_dir == "/Users/joe/html_dir"
@@ -602,7 +628,7 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
 
         assert cov.config.paths == {
             'source': ['.', '/home/ned/src/'],
-            'other': ['other', '/home/ned/other', 'c:\\Ned\\etc']
+            'other': ['other', '/home/ned/other', 'c:\\Ned\\etc'],
         }
 
         assert cov.config.get_plugin_options("plugins.a_plugin") == {
